# Test Coverage Report

Generated: Thu 2013-12-19 21:13 GMT

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 836 | 413 | 112 | 57.0%
ftp_deploy.models.log | 19 | 15 | 4 | 100.0%
ftp_deploy.models.notification | 39 | 36 | 3 | 100.0%
ftp_deploy.models.service | 57 | 38 | 9 | 79.2%
ftp_deploy.server.forms.login | 14 | 9 | 5 | 100.0%
ftp_deploy.server.forms.notification | 22 | 16 | 6 | 100.0%
ftp_deploy.server.forms.service | 33 | 27 | 6 | 100.0%
ftp_deploy.server.templatetags.active_tag | 14 | 10 | 4 | 100.0%
ftp_deploy.server.views.log | 30 | 19 | 7 | 82.6%
ftp_deploy.server.views.login | 28 | 21 | 7 | 100.0%
ftp_deploy.server.views.notification | 38 | 22 | 6 | 68.8%
ftp_deploy.server.views.service | 146 | 51 | 17 | 39.5%
ftp_deploy.utils.core | 76 | 41 | 7 | 59.4%
ftp_deploy.utils.curl | 25 | 7 | 3 | 31.8%
ftp_deploy.utils.decorators | 11 | 11 | 0 | 100.0%
ftp_deploy.utils.email | 91 | 67 | 7 | 79.8%
ftp_deploy.utils.ftp | 54 | 12 | 3 | 23.5%
ftp_deploy.utils.repo | 50 | 7 | 4 | 15.2%
ftp_deploy.views | 89 | 4 | 14 | 5.3%

Excluded packages and modules
Error packages and modules